# General Utilities

A General Utilities Library that provides a Python interface to many technologies

Available **Objects**:
1. RabbitMQ for queueing purpose
2. Redis as a secondary storage
3. MinIO for storing and retrieving files
4. API requests module

Available **Methods**:
1. Logging module

Kindly reffer the docstrings for further details reagriding the objects and methods :

```python
from general_utils import utils

help(utils)
##-- OR --##
print(utils.__doc__)
```

